Index: wp-includes/general-template.php
===================================================================
--- wp-includes/general-template.php	(revision 23791)
+++ wp-includes/general-template.php	(working copy)
@@ -141,7 +141,7 @@
  * form into the sidebar and also by the search widget in WordPress.
  *
  * There is also an action that is called whenever the function is run called,
  * 'get_search_form'. This can be useful for outputting JavaScript that the
  * search relies on or various formatting that applies to the beginning of the
  * search. To give a few examples of what it can be used for.
  *
@@ -151,7 +151,7 @@
  * @return string|null String when retrieving, null when displaying or if searchform.php exists.
  */
 function get_search_form( $echo = true, $format = 'xhtml' ) {
-	do_action( 'get_search_form' );
+	do_action( 'pre_get_search_form' );
 
 	$search_form_template = locate_template( 'searchform.php' );
 	if ( '' != $search_form_template ) {
@@ -141,7 +141,7 @@
  *
  * There is also an action that is called whenever the function is run called,
- * 'get_search_form'. This can be useful for outputting JavaScript that the
+ * 'pre_get_search_form'. This can be useful for outputting JavaScript that the
  * search relies on or various formatting that applies to the beginning of the
  * search. To give a few examples of what it can be used for.
